@@ -518,6 +518,13 @@ failed to upload.</source>
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>DataManager</name>
+    <message>
+        <source>Another copy or move operation is in progress. Please wait until it finishes.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DownloadRepoDialog</name>
     <message>
@@ -1384,10 +1391,6 @@ Do you like to download your default library?</source>
         <source>Please enter the computer name</source>
         <translation>Vul de computernaam in</translation>
     </message>
-    <message>
-        <source>Failed to save current account</source>
-        <translation>Mislukt om de huidige account op te slaan</translation>
-    </message>
     <message>
         <source>%1 Server Address</source>
         <translation type="unfinished"/>
@@ -2524,10 +2527,6 @@ File path contains invalid characters. It is not synced to this computer.</sourc
 </context>
 <context>
     <name>SeafileApplet</name>
-    <message>
-        <source>failed to add default account</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Failed to initialize log: %s</source>
         <translation>Mislukt om de log te initialiseren: %s</translation>
@@ -3141,6 +3140,13 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>SyncErrorsTableView</name>
+    <message>
+        <source>Delete file sync error failed</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>TwoFactorDialog</name>
     <message>
