@@ -520,6 +520,13 @@ failed to upload.</source>
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>DataManager</name>
+    <message>
+        <source>Another copy or move operation is in progress. Please wait until it finishes.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DownloadRepoDialog</name>
     <message>
@@ -1388,10 +1395,6 @@ Do you like to download your default library?</source>
         <source>Please enter the computer name</source>
         <translation>請輸入此計算機的代號</translation>
     </message>
-    <message>
-        <source>Failed to save current account</source>
-        <translation>無法儲存目前帳號</translation>
-    </message>
     <message>
         <source>%1 Server Address</source>
         <translation type="unfinished"/>
@@ -2529,10 +2532,6 @@ File path contains invalid characters. It is not synced to this computer.</sourc
 </context>
 <context>
     <name>SeafileApplet</name>
-    <message>
-        <source>failed to add default account</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Failed to initialize log: %s</source>
         <translation>無法初始化日誌: %s</translation>
@@ -3146,6 +3145,13 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>SyncErrorsTableView</name>
+    <message>
+        <source>Delete file sync error failed</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>TwoFactorDialog</name>
     <message>
