@@ -418,7 +418,7 @@ protected slots:
 
 private:
     Q_DISABLE_COPY(ServerInfoRequest);
-    const Account& account_;
+    const Account account_;
 };
 
 class LogoutDeviceRequest : public SeafileApiRequest
